Module web

Module web 

Structs

AllowlistWebPermissions
Permissions manager for the web related extensions
DefaultWebPermissions
The default permissions manager for the web related extensions
WebOptions
Options for configuring the web related extensions
init_web
An extension for use with the Deno JS runtime. To use it, provide it as an argument when instantiating your runtime:

Enums

SystemsPermissionKind
Knows systems permission checks performed by deno

Traits

WebPermissions
Trait managing the permissions for the web related extensions

Functions

extensions